@@ -175,8 +175,8 @@ if __name__ == '__main__':
 
     os.system("cd " + cacheDir)
     print(os.getcwd()+"\n\n\n")
-    os.system("pdflatex -output-directory=" +cacheDir +" "+ cacheDir+ "\\" +filename    + ".tex")
-    os.system("move " + cacheDir+"\\"+filename + ".pdf " + invoiceDir)
+    #os.system("pdflatex -output-directory=" +cacheDir +" "+ cacheDir+ "\\" +filename    + ".tex")
+    #os.system("move " + cacheDir+"\\"+filename + ".pdf " + invoiceDir)
     win1.close()
 
 
